Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(71)

Unified Diff: src/base/bits.h

Issue 502803002: Rename CountSetBits32 to CountPopulation32 for consistency. (Closed) Base URL: git@github.com:v8/v8.git@master
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/compiler/arm/instruction-selector-arm.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/base/bits.h
diff --git a/src/base/bits.h b/src/base/bits.h
index 129bf6268c677ae0a562630565508e24f54853a3..04a0300a66542785b177cf60884e44ba52914e23 100644
--- a/src/base/bits.h
+++ b/src/base/bits.h
@@ -17,8 +17,8 @@ namespace v8 {
namespace base {
namespace bits {
-// CountSetBits32(value) returns the number of bits set in |value|.
-inline uint32_t CountSetBits32(uint32_t value) {
+// CountPopulation32(value) returns the number of bits set in |value|.
+inline uint32_t CountPopulation32(uint32_t value) {
#if V8_HAS_BUILTIN_POPCOUNT
return __builtin_popcount(value);
#else
@@ -47,7 +47,7 @@ inline uint32_t CountLeadingZeros32(uint32_t value) {
value = value | (value >> 4);
value = value | (value >> 8);
value = value | (value >> 16);
- return CountSetBits32(~value);
+ return CountPopulation32(~value);
#endif
}
« no previous file with comments | « no previous file | src/compiler/arm/instruction-selector-arm.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698